Function is_log_fd

pub fn is_log_fd(fd: i32) -> bool
Check whether a file descriptor has been opened via DLog.

Use for low-level code that does bulk operations on FDs (for example, close them all) but still wants to be able to use DLog interfaces afterwards.

Returns

  • bool - Whether the descriptor refers to a DLog file.